# gdpshow

# This module gdpshow created for visualization any countries.

# input:text_file(format: "countryname1","countryname2"...)

# [![Open in Code Ocean](https://codeocean.com/codeocean-assets/badge/open-in-code-ocean.svg)](https://codeocean.com/capsule/4474279/tree/v1)